package com.example.modular.global.components;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.TimeZone;

import org.apache.wicket.ajax.markup.html.navigation.paging.AjaxPagingNavigator;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.PageableListView;
import org.apache.wicket.markup.html.panel.Panel;

/**
 * Available time zones panel. This component shows table with all available time zones. It uses
 * AXAJ for paging.
 * 
 * @author Krzysztof Smigielski
 */
public class AvailableTZonesPanel extends Panel {

    private static final long serialVersionUID = 4769725626314683178L;

    private List<String> zones;

    public AvailableTZonesPanel(String id) {
        super(id);
        add(new Label("header", "All available time zones page"));

        // list of available time zones
        zones = Arrays.asList(TimeZone.getAvailableIDs());
        Collections.sort(zones);

        PageableListView<String> listView = new PageableListView<String>("row", zones, 10) {
            private static final long serialVersionUID = -1018040987956954418L;

            private SimpleDateFormat date = new SimpleDateFormat("dd.MM.yyyy hh:mm:ss aaa (z)",
                            Locale.ENGLISH);

            @Override
            protected void populateItem(ListItem<String> item) {
                String timeZoneId = item.getDefaultModelObjectAsString();
                item.add(new Label("name", timeZoneId));
                TimeZone timeZone = TimeZone.getTimeZone(timeZoneId);
                date.setTimeZone(timeZone);
                item.add(new Label("date", date.format(new Date())));
            }
        };

        add(listView);
        // adds AJAX behavior for table elements paging
        add(new AjaxPagingNavigator("navigator", listView));
        setOutputMarkupId(true);
    }
}
