package com.example.modular.global.components;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.AjaxFallbackLink;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.PropertyModel;

import com.example.modular.global.pages.AvailableTZonesPage;
import com.example.modular.global.pages.LondonPage;
import com.example.modular.global.pages.RandomTzPage;
import com.example.modular.global.pages.TokyoPage;
import com.example.modular.warsaw.pages.WarsawPage;

/**
 * Panel used to navigate between different time zone pages.
 * 
 * @author Krzysztof Smigielski
 */
public class NavigationPanel extends Panel {

    private static final long serialVersionUID = 8738540967728215622L;

    private int classicClickCount = 0;

    private int ajaxClickCount = 0;

    /**
     * Default constructor.
     * 
     * @param pWicketId Wicket component id.
     */
    public NavigationPanel(String pWicketId) {
        super(pWicketId);

        add(new Label("header", "Current time and date in other time zones"));

        add(new ForwardLink("warsawLink", "Show time and date in Warsaw", WarsawPage.class));
        add(new ForwardLink("londonLink", "Show time and date in London", LondonPage.class));
        add(new ForwardLink("tokyoLink", "Show time and date in Tokyo", TokyoPage.class));

        ForwardLink randomPageLink = new ForwardLink("randomLink",
                        "Show time and date in a random time zone", RandomTzPage.class);
        // disable AutoEnable feature, that is responsible for deactivating link
        // that points to the current page. In this case link is always active.
        randomPageLink.setAutoEnable(false);
        add(randomPageLink);

        add(new ForwardLink("allLink", "Show all available time zones", AvailableTZonesPage.class));

        initCountingLinks();
    }

    /**
     * Initialize two links that counts number of times user has clicked them. One of them is a
     * classic link that causes whole page reload. Second link is an AJAX component that causes only
     * counter label to be reloaded.
     */
    private void initCountingLinks() {
        // classic link - whole page is reloaded
        add(new Label("classicClickLabel", new PropertyModel<String>(this, "classicClickCount")));
        add(new Link<String>("classicLink") {
            private static final long serialVersionUID = -2624246592434096491L;

            @Override
            public void onClick() {
                classicClickCount++;
            }
        });

        // AJAX link - only selected component is updated
        final Label label = new Label("ajaxClickLabel", new PropertyModel<String>(this, "ajaxClickCount"));
        label.setOutputMarkupId(true);
        add(label);
        add(new AjaxFallbackLink<String>("ajaxLink") {
            private static final long serialVersionUID = -8394747750716927915L;

            @Override
            public void onClick(AjaxRequestTarget pTarget) {
                ajaxClickCount++;
                if (pTarget != null) {
                    // update label component
                    pTarget.addComponent(label);
                }
            }
        });
    }

}
