package com.example.modular.global.components;

import org.apache.wicket.ajax.AjaxSelfUpdatingTimerBehavior;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.spring.injection.annot.SpringBean;
import org.apache.wicket.util.time.Duration;

import com.example.modular.global.common.RandomTzService;
import com.example.modular.warsaw.components.TimeZoneLink;

/**
 * Random time zone panel. Each instance of this class is associated with
 * randomly chosen time zone.
 * 
 * @author Krzysztof Smigielski
 */
public class RandomTzPanel extends Panel {

    private static final long serialVersionUID = -6790237862819698L;

    @SpringBean
    private RandomTzService tzService;

    /**
     * Default constructor.
     * 
     * @param pWicketId Wicket component id.
     */
    public RandomTzPanel(String pWicketId) {
        super(pWicketId);
        add(new Label("header", "Random time zone page"));
        
        TimeZoneLink ajaxTimeZone = new TimeZoneLink("tzLink", tzService.getRandomTimeZoneId());
        add(ajaxTimeZone);
        // add AJAX self updating behavior
        ajaxTimeZone.add(new AjaxSelfUpdatingTimerBehavior(Duration.seconds(1)));
    }

    public void setTzService(RandomTzService pTzService) {
        tzService = pTzService;
    }

}
